@@ -3,7 +3,7 @@
 #include <QFileSystemModel>
 #include <QTreeView>
 #include <QListWidget>
-#include <Phonon>
+#include <phonon>
 #include <QPushButton>
 //#include <QMaemo5InformationBox>
 #include "mainwindow.h"
@@ -20,7 +20,10 @@
 #include "symfonieaboutdialog.h"
 #include "symfonietimerwindow.h"
 #include "symfonieequalizerwindow.h"
-
+#include "symfoniefiletypesdialog.h"
+#include "symfoniefullscreenexitbutton.h"
+#include "symfonieoptionsdialog.h"
+#include "symfonievolumeslider.h"
 
 
 MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent) :
@@ -28,18 +31,26 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         app(app),
         ui(new Ui::MainWindow),
         timerWindow(NULL),
+        fileTypesDialog(NULL),
+        optionsDialog(NULL),
         player(player),
-        equalizerWindow(new SymfonieEqualizerWindow(this->getPlayer()->getEqualizerEffect(), this)),
-
+        equalizerWindow(new SymfonieEqualizerWindow(this)),
+        currentOrientationMode(Qt::WA_Maemo5LandscapeOrientation),
         isInPortait(false),
         isResumePlayback(false)
 {
+    this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
 
     setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
 
+
     this->ui->mainToolBar2->hide();
 
+
+
+
+
     //set up menus
     orientationGroup = new QActionGroup(this);
     orientationGroup->setExclusive(true);
@@ -57,18 +68,28 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     this->ui->menuBar->addActions(orientationGroup->actions());
 
-    connect(orientationGroup, SIGNAL(triggered(QAction *)), this, SLOT(orientationChanged(QAction *)));
+
+
+
+
     // connect(a1, SIGNAL(triggered()), this, SLOT(toggleFullScreenOn()));
     //connect(a2, SIGNAL(triggered()), this, SLOT(toggleFullScreenOff()));
 
 
 
+
+    connect(this->ui->menuActionFileTypes, SIGNAL(triggered()), this, SLOT(showFileTypesWindowSlot()));
+
+    connect(this->ui->menuActionOptions, SIGNAL(triggered()), this, SLOT(showOptionsWindowSlot()));
+
+
     this->toggleFullScreenAction = new QAction(QIcon::fromTheme("general_fullsize"), QString(), this);
     this->toggleFullScreenAction->setCheckable(true);
     connect(this->toggleFullScreenAction, SIGNAL(toggled(bool)), this, SLOT(toggleFullScreen(bool)));
 
 
 
+
     connect(this->getPlayer(), SIGNAL(timerStoppedSignal()), this, SLOT(playerTimerStoppedSlot()));
     connect(this->getPlayer(), SIGNAL(timerRemainTimeChangedSignal(int)), this, SLOT(playerTimerRemainTimeChangedSlot(int)));
 
@@ -82,6 +103,16 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     connect(this->ui->menuActionTimer, SIGNAL(triggered()), this, SLOT(showTimerWindowSlot()));
 
+
+
+    //init equalizer window
+    bool isEqualizerEnabled = SymfonieDb::getInstance()->getSetting("is_equalizer_enabled", QVariant(0)).toInt() == 0 ? false : true;
+
+    connect(this->equalizerWindow,  SIGNAL(enabledStateChanged(bool)), this, SLOT(equalizerWindowEnabledStateChangedSlot(bool)));
+    qDebug() << " this->equalizerWindow->setWindowEnabled(isEqualizerEnabled);" << isEqualizerEnabled;
+    this->equalizerWindow->setWindowEnabled(isEqualizerEnabled);
+
+
     connect(this->ui->menuActionEqualizer, SIGNAL(triggered()), this, SLOT(showEqualizerWindowSlot()));
 
 
@@ -90,7 +121,6 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
     this->ui->subToolBar->hide();
-    this->ui->subToolBar2->hide();
 
 
     //this->ui->fileListWidget->setItemDelegate(new SymfonieRichTextDelegate());
@@ -102,38 +132,46 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
 
-    this->volumeSlider = new Phonon::VolumeSlider(this->getPlayer()->getAudioOutput(), this);
+
+    this->volumeSlider = new SymfonieVolumeSlider(this->getPlayer()->getAudioOutput(), this);
     //this->volumeSlider->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
 
 
 
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 
+
+
+    this->fullScreenExitButton = new SymfonieFullScreenExitButton(this);
+
+    this->ui->sliderLabel->setParent(this);
+    this->seekSlider->installEventFilter(this->ui->sliderLabel);
+
     //button2  = new QPushButton("Click here to open another stacked window", this);
     // button2->setAttribute(Qt::WA_Maemo5StackedWindow);
     //  button2->setWindowFlags(button2->windowFlags() | Qt::Window);
 
 
     playAction = new QAction(style()->standardIcon(QStyle::SP_MediaPlay), tr("Play"), ui->mainToolBar);
-    playAction->setShortcut(tr("Crl+A"));
+    // playAction->setShortcut(tr("Crl+A"));
     //playAction->setDisabled(true);
 
     stopAction = new QAction(style()->standardIcon(QStyle::SP_MediaStop), tr("Stop"), ui->mainToolBar);
-    stopAction->setShortcut(tr("Crl+S"));
+    // stopAction->setShortcut(tr("Crl+S"));
     // stopAction->setDisabled(true);
 
     prevAction = new QAction(style()->standardIcon(QStyle::SP_MediaSkipBackward), tr("Previous"), ui->mainToolBar);
-    prevAction->setShortcut(tr("Crl+R"));
+    //  prevAction->setShortcut(tr("Crl+R"));
 
 
     nextAction = new QAction(style()->standardIcon(QStyle::SP_MediaSkipForward), tr("Next"), ui->mainToolBar);
-    nextAction->setShortcut(tr("Crl+N"));
+    // nextAction->setShortcut(tr("Crl+N"));
 
 
 
 
 
-    this->goUpAction =  new QAction(style()->standardIcon(QStyle::SP_ArrowUp), tr("Go Up"), ui->mainToolBar);
+    this->goUpAction =  new QAction(QIcon::fromTheme("filemanager_folder_up"), tr("Go Up"), ui->mainToolBar);
     connect(goUpAction, SIGNAL(triggered()), this, SLOT(goUpSlot()));
 
     this->switchOrientationAction = new QAction(style()->standardIcon(QStyle::SP_BrowserReload),
@@ -145,16 +183,16 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(showInfoWindowAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-    this->showToolBar2Action  = new QAction(style()->standardIcon(QStyle::SP_MediaVolume), tr("Show Volume"), ui->mainToolBar);
+    this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume"), ui->mainToolBar);
     this->showToolBar2Action->setCheckable(true);
     connect(showToolBar2Action, SIGNAL(triggered()), this, SLOT(showToolBar2Slot()));
 
 
-    this->goHomeAction = new QAction(style()->standardIcon(QStyle::SP_ComputerIcon), tr("Go Home"), ui->mainToolBar);
+    this->goHomeAction = new QAction(QIcon::fromTheme("general_device_root_folder"), tr("Go Home"), ui->mainToolBar);
     connect(goHomeAction, SIGNAL(triggered()), this, SLOT(goHomeSlot()));
 
 
-    this->goToCurDir = new QAction(style()->standardIcon(QStyle::SP_DesktopIcon), tr("Go to current directory"), ui->mainToolBar);
+    this->goToCurDir = new QAction(QIcon::fromTheme("imageviewer_rotate"), tr("Go to current directory"), ui->mainToolBar);
     connect(goToCurDir, SIGNAL(triggered()), this, SLOT(goToCurDirSlot()));
 
     connect(playAction, SIGNAL(triggered()), this, SLOT(playSlot()));
@@ -170,18 +208,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-    this->ui->mainToolBar->addAction(this->goHomeAction);
-    this->ui->mainToolBar->addAction(this->goUpAction);
-    this->ui->mainToolBar->addAction(this->goToCurDir);
-
-    ui->mainToolBar->addAction(prevAction);
-    ui->mainToolBar->addAction(playAction);
-    // ui->mainToolBar->addAction(stopAction);
-    ui->mainToolBar->addAction(nextAction);
-
-    ui->mainToolBar->addAction(showInfoWindowAction);
-    ui->mainToolBar->addAction(this->showToolBar2Action);
-    ui->mainToolBar->addAction(this->toggleFullScreenAction);
+    //this->addToolBarButtonsLandscape();
 
 
 
@@ -189,7 +216,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     qDebug() << this->ui->mainToolBar->height();
 
     //eq->show();
-    this->ui->subToolBar2->addWidget(this->volumeSlider);
+    this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
 
 
 
@@ -200,7 +227,9 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     //ui->mainToolBar->addWidget(slider);
     connect(this->player, SIGNAL(scanDirCompletedSignal(SymfoniePlayList*, QString)),
             this, SLOT(playerScanDirCompletedSlot(SymfoniePlayList*, QString)));
-    this->player->init();
+
+
+    this->setupToolBarButtonsLandscape();
 
 
     QString lastPlayedFile = SymfonieDb::getInstance()->getSetting("last_played_file").toString();
@@ -227,16 +256,68 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     // this->player->scanDir(this->getCurrentDiretory(), true);
 
 
+    this->ui->fileListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
+    connect(this->ui->fileListWidget, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(fileListItemContextMenu(const QPoint &)));
+
+
+
+
     connect(this->ui->fileListWidget, SIGNAL(activated(QModelIndex)),
             this, SLOT(itemActivatedSlot(QModelIndex)));
 
 
+
+    if(SymfonieDb::getInstance()->getSetting("is_show_main_toolbar", 1).toInt() == 1){
+        this->ui->mainToolBar->show();
+    }else{
+        this->ui->mainToolBar->hide();
+    }
+
+
+    if(SymfonieDb::getInstance()->getSetting("is_show_volume_slider", 0).toInt() == 1){
+        this->ui->volumePanel->show();
+    }else{
+        this->ui->volumePanel->hide();
+    }
+
     //this->setHO();
 
+    int testOrientationMode = SymfonieDb::getInstance()->getSetting("orientation_mode", QVariant(Qt::WA_Maemo5LandscapeOrientation)).toInt();
+
+    if(testOrientationMode == Qt::WA_Maemo5AutoOrientation){
+        //this->orientationAuto->trigger();
+        setOrientationMode(Qt::WA_Maemo5AutoOrientation);
+    }else if(testOrientationMode == Qt::WA_Maemo5PortraitOrientation){
+        //this->orientationPortrait->trigger();
+        setOrientationMode(Qt::WA_Maemo5PortraitOrientation);
+    }else{
+        //this->orientationLandscape->trigger();
+        setOrientationMode(Qt::WA_Maemo5LandscapeOrientation);
+    }
+
+
+     connect(orientationGroup, SIGNAL(triggered(QAction *)), this, SLOT(orientationChanged(QAction *)));
+
+
 }
 
+void MainWindow::deleteFileSlot(){
 
 
+}
+
+void MainWindow::fileListItemContextMenu(const QPoint &pos){
+    QMenu *menu = new QMenu;
+    menu->addAction(tr("Delete File"), this, SLOT(deleteFileSlot()));
+    menu->exec(this->mapToGlobal(pos));
+
+
+}
+
+Ui::MainWindow* MainWindow::getUi(){
+    return this->ui;
+}
+
 MainWindow::~MainWindow()
 {
 
@@ -257,12 +338,65 @@ MainWindow::~MainWindow()
     if(this->timerWindow != NULL){
         delete this->timerWindow;
     }
-    if(this->equalizerWindow != NULL){
-        delete this->equalizerWindow;
-    }
     delete this->player;
+
+    delete this->equalizerWindow;
+
+    if(this->fileTypesDialog != NULL){
+        delete this->fileTypesDialog;
+    }
+
+    if(this->optionsDialog != NULL){
+        delete this->optionsDialog;
+    }
+
+
 }
 
+
+
+
+void MainWindow::setupToolBarButtonsLandscape(){
+    this->ui->mainToolBar->clear();
+    this->ui->mainToolBar->addAction(this->goHomeAction);
+    this->ui->mainToolBar->addAction(this->goUpAction);
+    this->ui->mainToolBar->addAction(this->goToCurDir);
+
+    this->ui->mainToolBar->addAction(prevAction);
+    this->ui->mainToolBar->addAction(playAction);
+    this->ui->mainToolBar->addAction(nextAction);
+
+    this->ui->mainToolBar->addAction(showInfoWindowAction);
+    this->ui->mainToolBar->addAction(this->showToolBar2Action);
+    //this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
+
+    this->ui->mainToolBar2->hide();
+}
+
+
+void MainWindow::setupToolBarButtonsPortrait(){
+    this->ui->mainToolBar->clear();
+    this->ui->mainToolBar2->clear();
+
+
+    this->ui->mainToolBar2->addAction(prevAction);
+    this->ui->mainToolBar2->addAction(playAction);
+    this->ui->mainToolBar2->addAction(nextAction);
+
+    this->ui->mainToolBar2->addAction(showInfoWindowAction);
+    this->ui->mainToolBar2->addAction(this->showToolBar2Action);
+
+
+    this->ui->mainToolBar->addAction(this->goHomeAction);
+    this->ui->mainToolBar->addAction(this->goUpAction);
+    this->ui->mainToolBar->addAction(this->goToCurDir);
+    // this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
+
+
+    this->ui->mainToolBar2->show();
+}
+
+
 void MainWindow::playerTimerStoppedSlot(){
     if(this->timerWindow != NULL){
         this->timerWindow->setTimerStateEnabled(false);
@@ -271,48 +405,36 @@ void MainWindow::playerTimerStoppedSlot(){
 
 void MainWindow::orientationChanged(QAction *action)
 {
-
-
     if (action == this->orientationAuto){
-        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-
+        this->setOrientationMode(Qt::WA_Maemo5AutoOrientation);
     }else if (action == this->orientationPortrait){
+        this->setOrientationMode(Qt::WA_Maemo5PortraitOrientation);
+    }else{
+        this->setOrientationMode(Qt::WA_Maemo5LandscapeOrientation);
+    }
+}
+
+void MainWindow::setOrientationMode(int mode){
+    if (mode == Qt::WA_Maemo5AutoOrientation){
+        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+        this->setupToolBarButtonsLandscape();
+    }else if (mode == Qt::WA_Maemo5PortraitOrientation){
         setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-        this->ui->mainToolBar2->addAction(this->goHomeAction);
-        this->ui->mainToolBar2->addAction(this->goUpAction);
-        this->ui->mainToolBar2->addAction(this->goToCurDir);
-        this->ui->mainToolBar2->addAction(this->toggleFullScreenAction);
-
-
-
-        this->ui->mainToolBar->removeAction(this->goHomeAction);
-        this->ui->mainToolBar->removeAction(this->goUpAction);
-        this->ui->mainToolBar->removeAction(this->goToCurDir);
-        this->ui->mainToolBar->removeAction(this->toggleFullScreenAction);
-
-        this->ui->mainToolBar2->show();
+        this->setupToolBarButtonsPortrait();
     }else{
         setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-        this->ui->mainToolBar->addAction(this->goHomeAction);
-        this->ui->mainToolBar->addAction(this->goUpAction);
-        this->ui->mainToolBar->addAction(this->goToCurDir);
-        this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
-
-        this->ui->mainToolBar2->removeAction(this->goHomeAction);
-        this->ui->mainToolBar2->removeAction(this->goUpAction);
-        this->ui->mainToolBar2->removeAction(this->goToCurDir);
-        this->ui->mainToolBar2->removeAction(this->toggleFullScreenAction);
-        this->ui->mainToolBar2->hide();
-
+        this->setupToolBarButtonsLandscape();
     }
-
-    this->orientationLandscape->setChecked(action == this->orientationLandscape);
-    this->orientationPortrait->setChecked(action == this->orientationPortrait);
-    this->orientationAuto->setChecked(action == this->orientationAuto);
-
+/*
+    this->orientationLandscape->setChecked(mode == Qt::WA_Maemo5LandscapeOrientation);
+    this->orientationPortrait->setChecked(mode == Qt::WA_Maemo5PortraitOrientation);
+    this->orientationAuto->setChecked(mode == Qt::WA_Maemo5AutoOrientation);
+  */
+      this->currentOrientationMode = mode;
 
 }
 
+
 void MainWindow::toggleFullScreenOn(){
     toggleFullScreen(true);
 }
@@ -321,10 +443,16 @@ void MainWindow::toggleFullScreenOff(){
     toggleFullScreen(false);
 }
 
+void MainWindow::toggleFullScreen(){
+    bool isFullScreen = this->windowState() & Qt::WindowFullScreen;
+    this->toggleFullScreen(!isFullScreen);
+
+}
 
 void MainWindow::toggleFullScreen(bool b)
 {
     qDebug() << "toggleFullScreen: " << b;
+    this->ui->volumePanel->hide();
     setWindowState(b ? windowState() | Qt::WindowFullScreen
         : windowState() & ~Qt::WindowFullScreen);
 }
@@ -350,6 +478,73 @@ void MainWindow::setMenuActionTimerText(int time){
 
 }
 
+void MainWindow::equalizerWindowEnabledStateChangedSlot(bool value){
+    qDebug() << "equalizerWindowEnabledStateChangedSlot called" << value;
+    if(value){
+        if(this->getPlayer()->insertEqualizerEffect()){
+            this->equalizerWindow->setEqualizerEffect(this->getPlayer()->getEqualizerEffect());
+
+        }
+    }else{
+        this->getPlayer()->removeEqualizerEffect();
+    }
+}
+
+
+void MainWindow::showFileTypesWindowSlot(){
+    if(this->fileTypesDialog == NULL){
+        this->fileTypesDialog = new SymfonieFileTypesDialog(this);
+        connect(this->fileTypesDialog, SIGNAL(fileTypesChanged(QStringList)),
+                this, SLOT(fileTypesChangedSlot(QStringList)));
+    }
+
+    qDebug() << "this->fileTypesDialog->exec()" << this->fileTypesDialog->exec();
+}
+
+
+int MainWindow::getCurrentOrientation(){
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    if (screenGeometry.width() > screenGeometry.height()){
+        return Qt::WA_Maemo5LandscapeOrientation;
+    }else{
+        return Qt::WA_Maemo5PortraitOrientation;
+    }
+}
+
+void MainWindow::showOptionsWindowSlot(){
+    if(this->optionsDialog == NULL){
+        this->optionsDialog = new SymfonieOptionsDialog(this);
+        connect(this->optionsDialog, SIGNAL(finished(int)),
+                this, SLOT(optionsChangedSlot(int)));
+    }
+
+    this->optionsDialog->exec();
+}
+
+
+void MainWindow::setToolbarVisibility(bool isShow){
+    if(isShow){
+        this->ui->mainToolBar->show();
+        if(this->getCurrentOrientation() == Qt::WA_Maemo5PortraitOrientation){
+            this->ui->mainToolBar2->show();
+        }
+    }else{
+
+        this->ui->mainToolBar->hide();
+        this->ui->mainToolBar2->hide();
+    }
+    this->resize(this->sizeHint());
+}
+
+void MainWindow::optionsChangedSlot(int){
+    this->setToolbarVisibility(this->optionsDialog->getOptionIsShowToolbar());
+}
+
+
+void MainWindow::fileTypesChangedSlot(QStringList list){
+    this->getPlayer()->setFileFilter(list);
+}
+
 void MainWindow::playerTimerRemainTimeChangedSlot(int time){
     qDebug() << "playerTimerRemainTimeChangedSlot: " << time;
 
@@ -360,21 +555,28 @@ void MainWindow::playerTimerRemainTimeChangedSlot(int time){
 
 
 
-  //  if(this->ui->mainMenu->isActiveWindow()){
+    //  if(this->ui->mainMenu->isActiveWindow()){
     /** @todo optimize this, only do this when menu is shown */
-        this->setMenuActionTimerText(time);
-   // }
+    this->setMenuActionTimerText(time);
+    // }
 
 }
 
 
 void MainWindow::goUpSlot(){
-    qDebug() << this->curentDirectory;
-    if(this->getCurrentDiretory().length() == 0){
+
+    QDir homeDir = QDir(QDir::homePath() + "/MyDocs");
+    QDir mediaDir = QDir("/media");
+    qDebug() << "sdflskjadf=-===========: "<< homeDir.canonicalPath() << this->getCurrentDiretory();
+
+
+    if(this->getCurrentDiretory().length() == 0 ||
+       QString::compare(homeDir.canonicalPath(), this->getCurrentDiretory()) == 0 ||
+       QString::compare(mediaDir.canonicalPath(), this->getCurrentDiretory()) == 0
+       ){
         this->goHomeSlot();
     }else{
         QFileInfo info = QFileInfo(this->getCurrentDiretory() + "/..");
-        // qDebug() << "up to : " <<info.canonicalFilePath();
         this->getPlayer()->scanDir(info.canonicalFilePath());
     }
 }
@@ -395,15 +597,18 @@ bool MainWindow::saveLastDir(){
 
 void MainWindow::saveState(){
     this->saveLastDir();
-    qDebug() << "curent time: "<<this->getPlayer()->getMediaObject()->currentTime();
-    if(this->getPlayer()->getCurrentPlaybackIndex() != -1){
-        SymfonieDb::getInstance()->saveSetting("last_played_position", QVariant(this->getPlayer()->getMediaObject()->currentTime()));
-    }else{
-        SymfonieDb::getInstance()->saveSetting("last_played_position", QVariant(0));
-    }
+    // qDebug() << "curent time: "<<this->getPlayer()->getMediaObject()->currentTime();
 
-    SymfonieDb::getInstance()->saveSetting("is_seekSlider_visible", QVariant(this->ui->subToolBar->isVisible() ? 1:1));
-    qDebug() << "is_seekSlider_visible" << SymfonieDb::getInstance()->getSetting("is_seekSlider_visible");
+
+    SymfonieDb::getInstance()->saveSetting("is_seekSlider_visible", QVariant(this->ui->subToolBar->isVisible() ? 1:0));
+    //qDebug() << "is_seekSlider_visible" << SymfonieDb::getInstance()->getSetting("is_seekSlider_visible");
+
+    SymfonieDb::getInstance()->saveSetting("orientation_mode", QVariant(this->currentOrientationMode));
+
+    if(this->optionsDialog != NULL){
+        SymfonieDb::getInstance()->saveSetting("is_show_main_toolbar", QVariant(this->optionsDialog->getOptionIsShowToolbar() ? 1:0));
+    }
+    SymfonieDb::getInstance()->saveSetting("is_show_volume_slider", QVariant(this->ui->volumePanel->isVisible() ? 1:0));
 }
 
 void MainWindow::showAboutWindowSlot(){
@@ -448,11 +653,36 @@ void MainWindow::playerTickSlot(qint64 time)
 
 SymfoniePlayList* MainWindow::createHomePlayList(){
     SymfoniePlayList *playList = new SymfoniePlayList();
-    SymfoniePlayListItemFolder *homeFolder = new SymfoniePlayListItemFolder(
-            QDir::homePath () + "/MyDocs/.sounds"
-            );
-    homeFolder->setDisplayName(tr("My Music"));
-    playList->addFolder(homeFolder);
+
+    QStringList stringList;
+
+    stringList
+            << QDir::homePath () + "/MyDocs/.sounds"
+            << "Audio clips"
+            << QDir::homePath () + "/MyDocs"
+            << "MyDocs";
+
+
+
+    for(int index=0; index < stringList.size(); index++){
+        QFileInfo fileInfo(stringList.at(index));
+        index++;
+        QString dirName = stringList.at(index);
+
+        SymfoniePlayListItemFolder *folder = new SymfoniePlayListItemFolder(
+                fileInfo.absoluteFilePath()
+                );
+        folder->setDisplayName(dirName);
+        playList->addFolder(folder);
+    }
+
+
+
+
+
+
+
+
 
     QString mediaPath = "/media";
     QDir mediaDir = QDir(mediaPath);
@@ -487,9 +717,11 @@ void MainWindow::goHomeSlot(){
 void MainWindow::showInfoWindowSlot(){
     if(this->ui->sliderPanel->isVisible()){
         this->ui->sliderPanel->hide();
+        this->ui->sliderLabel->hide();
         this->showInfoWindowAction->setChecked(false);
     }else{
         this->ui->sliderPanel->show();
+        this->ui->sliderLabel->show();
         this->showInfoWindowAction->setChecked(true);
     }
 
@@ -498,7 +730,7 @@ void MainWindow::showInfoWindowSlot(){
 
 void MainWindow::setActionToggleState(){
     this->showInfoWindowAction->setChecked(this->ui->subToolBar->isVisible());
-    this->showToolBar2Action->setChecked(this->ui->subToolBar2->isVisible());
+    this->showToolBar2Action->setChecked(this->ui->volumePanel->isVisible());
 }
 
 
@@ -506,11 +738,12 @@ void MainWindow::setActionToggleState(){
 
 void MainWindow::showToolBar2Slot(){
     qDebug() << "showToolBar2Slot()";
-    if(this->ui->subToolBar2->isVisible()){
-        this->ui->subToolBar2->hide();
+    if(this->ui->volumePanel->isVisible()){
+        this->ui->volumePanel->hide();
     }else{
-        this->ui->subToolBar2->show();
+        this->ui->volumePanel->show();
     }
+    //this->resize(this->sizeHint());
     this->setActionToggleState();
 }
 
@@ -572,11 +805,12 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
 
 
         if(item->getItemType() == SymfoniePlayListItem::Directory){
-            newItem->setIcon(style()->standardIcon(QStyle::SP_DirIcon));
+            newItem->setIcon(QIcon::fromTheme("filemanager_audio_folder"));
         }else if(item->getItemType() == SymfoniePlayListItem::File){
-            newItem->setIcon(style()->standardIcon(QStyle::SP_FileIcon));
+            newItem->setIcon(QIcon::fromTheme("general_audio_file"));
         }else if(item->getItemType() == SymfoniePlayListItem::DotDot){
-            newItem->setIcon(style()->standardIcon(QStyle::SP_ArrowUp));
+            newItem->setIcon(QIcon::fromTheme("filemanager_folder_up"));
+
         }
 
 
@@ -601,7 +835,6 @@ void MainWindow::insertItem(SymfoniePlayList* playList){
     }
 }
 
-
 void MainWindow::changeEvent(QEvent *e)
 {
     QMainWindow::changeEvent(e);
@@ -609,6 +842,7 @@ void MainWindow::changeEvent(QEvent *e)
     case QEvent::LanguageChange:
         ui->retranslateUi(this);
         break;
+
     default:
         break;
     }
@@ -625,14 +859,14 @@ void MainWindow::itemActivatedSlot(QModelIndex index)
     }
 
     QString path = item->getName();
-    qDebug() << "item index: " << index << " item at: " << path << item->getItemTypeName() << " curdir:" << this->getCurrentDiretory();
+    // qDebug() << "item index: " << index << " item at: " << path << item->getItemTypeName() << " curdir:" << this->getCurrentDiretory();
 
-    if(item->getItemType() == SymfoniePlayListItem::Directory ||
-       item->getItemType() == SymfoniePlayListItem::DotDot){
+    if(item->getItemType() == SymfoniePlayListItem::Directory){
         this->setCurrentDirectory(path);
         this->getPlayer()->scanDir(this->getCurrentDiretory());
-
-
+    }else if(item->getItemType() == SymfoniePlayListItem::DotDot){
+        //this->setCurrentDirectory(path);
+        this->goUpSlot();
     }else if(item->getItemType() == SymfoniePlayListItem::File){
         if(QString::compare(this->getCurrentDiretory(), this->getPlayer()->getCurrentDirectory()) == 0){
 
@@ -647,7 +881,7 @@ void MainWindow::itemActivatedSlot(QModelIndex index)
                 this->player->getMediaObject()->state() == Phonon::PlayingState ||
                 this->player->getMediaObject()->state() == Phonon::PausedState
                 )){
-           this->getPlayer()->playOrPause();
+            this->getPlayer()->playOrPause();
         }else{
             this->player->enqueue(row);
             this->player->play();
@@ -760,7 +994,7 @@ void MainWindow::playerScanDirCompletedSlot(SymfoniePlayList* playList, QString
     if(this->isResumePlayback == true){
         this->isResumePlayback = false;
         QVariant indexBuff = SymfonieDb::getInstance()->getSetting("last_played_index");
-        /** @todo QVariant doesn't seek to take qint64, potential information loss */
+        /** @todo QVariant doesn't seem to take qint64, potential information loss */
         qint64 seekTo = SymfonieDb::getInstance()->getSetting("last_played_position").toInt();
         if(indexBuff.toString().length() != 0){
             int index = indexBuff.toInt();
