@@ -5,7 +5,7 @@
 #include <QModelIndex>
 #include <QPushButton>
 #include <QAction>
-#include <Phonon>
+#include <phonon>
 #include <QListWidgetItem>
 
 
@@ -17,7 +17,10 @@ class QTimer;
 class QApplication;
 class SymfonieTimerWindow;
 class SymfonieEqualizerWindow;
-
+class SymfonieFileTypesDialog;
+class SymfonieOptionsDialog;
+class SymfonieFullScreenExitButton;
+class SymfonieVolumeSlider;
 
 namespace Ui {
     class MainWindow;
@@ -37,6 +40,9 @@ public:
     void setPO();
     void setHO();
 
+    Ui::MainWindow* getUi();
+    int getCurrentOrientation();
+
 
 protected:
     void changeEvent(QEvent *e);
@@ -51,7 +57,8 @@ private:
     SymfonieTimerWindow *timerWindow;
     SymfonieEqualizerWindow *equalizerWindow;
     const QApplication *app;
-
+    SymfonieFileTypesDialog *fileTypesDialog;
+    SymfonieOptionsDialog *optionsDialog;
 
     QAction *playAction;
     QAction *stopAction;
@@ -75,7 +82,7 @@ private:
 
     SymfonieInfoWindow* infoWindow;
     Phonon::SeekSlider *seekSlider;
-    Phonon::VolumeSlider *volumeSlider;
+    SymfonieVolumeSlider *volumeSlider;
 
     void setActionToggleState();
 
@@ -87,6 +94,15 @@ private:
 
     void setMenuActionTimerText(int time);
 
+   void setupToolBarButtonsLandscape();
+   void setupToolBarButtonsPortrait();
+   void setOrientationMode(int mode);
+   int currentOrientationMode;
+
+   SymfonieFullScreenExitButton *fullScreenExitButton;
+
+   void setToolbarVisibility(bool isShow);
+
 
 private Q_SLOTS:
     void itemActivatedSlot(QModelIndex);
@@ -108,6 +124,7 @@ private Q_SLOTS:
     void showTimerWindowSlot();
     void updateTimerSlot(int time);
     void showEqualizerWindowSlot();
+    void toggleFullScreen();
     void toggleFullScreen(bool b);
     void toggleFullScreenOn();
     void toggleFullScreenOff();
@@ -115,6 +132,15 @@ private Q_SLOTS:
     void playerTimerStoppedSlot();
     void clearTimerSlot();
     void playerTimerRemainTimeChangedSlot(int);
+    void equalizerWindowEnabledStateChangedSlot(bool value);
+    void showFileTypesWindowSlot();
+    void fileTypesChangedSlot(QStringList list);
+    void showOptionsWindowSlot();
+    void optionsChangedSlot(int);
+
+    void fileListItemContextMenu(const QPoint &pos);
+    void deleteFileSlot();
+
 
 };
 
