@@ -1,25 +1,35 @@
 #include <QDir>
 #include <QScrollArea>
 #include <QDesktopServices>
-#include <Phonon>
+#include <phonon>
 #include "symfoniemediaplayer.h"
 #include "symfonieplaylist.h"
 #include "symfonieplaylistitem.h"
 #include "symfonieplaylistitemfolder.h"
 #include "symfoniesong.h"
 #include "symfoniedb.h"
+#include "symfoniefiletypesdialog.h"
 
 SymfonieMediaPlayer::SymfonieMediaPlayer(QObject *parent) :
         QObject(parent),
         playList(NULL),
         timer(new QTimer()),
         timerUpdater(new QTimer()),
+        graduateVolumeTimer(new QTimer()),
+        equalizerEffect(NULL),
         currentPlaybackIndex(-1),
         queuedIndex(-1),
         seekToBuffer(-1),
-        timerRemainCounter(0){
+        timerRemainCounter(0),
+        hasEqualizerEffect(false),
+        isEqualizerEnabled(false),
+        graduateVolumeResumeTo(0)
+{
+    this->initPlayer();
+}
 
 
+void SymfonieMediaPlayer::initPlayer(){
     this->timer->setSingleShot(true);
     connect(timer, SIGNAL(timeout()), this, SLOT(timerEndSlot()));
 
@@ -31,8 +41,14 @@ SymfonieMediaPlayer::SymfonieMediaPlayer(QObject *parent) :
 
 
     this->audioOutput = new Phonon::AudioOutput;
+
+
     this->path = Phonon::createPath(player, audioOutput);
 
+
+    this->setFileFilter(SymfonieFileTypesDialog::getSavedFilterList());
+
+
     connect(this->player, SIGNAL(stateChanged(Phonon::State,Phonon::State)),
             this, SLOT(mediaStateChangedSlot(Phonon::State,Phonon::State)));
 
@@ -43,24 +59,18 @@ SymfonieMediaPlayer::SymfonieMediaPlayer(QObject *parent) :
     connect(this, SIGNAL(playListUpdatedSignal(SymfoniePlayList*)),
             this, SLOT(playListUpdatedSlot(SymfoniePlayList*)));
 
-    QList<Phonon::EffectDescription> effectDescriptions =
-            Phonon::BackendCapabilities::availableAudioEffects();
 
-    qDebug() << effectDescriptions.size() << " effect size";
-    for(int i = 0; i < effectDescriptions.size(); i++){
-        Phonon::EffectDescription ef = effectDescriptions.at(i);
-        if(QString::compare(ef.name(), "equalizer-10bands") == 0){
-            this->equalizerEffect = new Phonon::Effect(ef);
-            path.insertEffect(this->equalizerEffect );
-            qDebug() << "Effect inserted: " << ef.name();
-        }
-        qDebug() << ef.name();
-    }
+
 
 
     this->timerUpdater->setInterval(SymfonieMediaPlayer::TIMER_VALUE_UPDATE_RATE);
     connect(this->timerUpdater, SIGNAL(timeout()), this, SLOT(updateTimerValueSlot()));
 
+
+    connect(this->graduateVolumeTimer, SIGNAL(timeout()), this, SLOT(doGraduateVolumeResuming()));
+
+   //this->audioOutput->setVolume(0);
+
 }
 
 SymfonieMediaPlayer::~SymfonieMediaPlayer()
@@ -70,9 +80,77 @@ SymfonieMediaPlayer::~SymfonieMediaPlayer()
     delete audioOutput;
     delete this->timer;
     delete this->timerUpdater;
+    delete this->graduateVolumeTimer;
 
 }
 
+
+void SymfonieMediaPlayer::startGraduateVolumeResuming(qreal value){
+    this->graduateVolumeTimer->start(50);
+    this->graduateVolumeResumeTo = value;
+}
+
+
+void SymfonieMediaPlayer::doGraduateVolumeResuming(){
+   // qDebug() << "--------------doGraduateVolumeResuming()";
+   // qreal lower = 0;
+    qreal cur = this->audioOutput->volume();
+    qreal value = this->graduateVolumeResumeTo;
+    qreal inc = SymfonieMediaPlayer::GRADUATE_VOLUME_INCREMENT;
+
+/*
+    if(this->graduateVolumeResumeTo > lower && cur < lower){
+        cur = lower;
+    }
+    */
+
+    if(cur + inc > value){
+        this->audioOutput->setVolume(value);
+        this->graduateVolumeTimer->stop();
+    }else{
+        this->audioOutput->setVolume(cur + inc);
+    }
+}
+
+
+bool SymfonieMediaPlayer::insertEqualizerEffect(){
+    if(!this->isEqualizerEnabled){
+        QList<Phonon::EffectDescription> effectDescriptions =
+                Phonon::BackendCapabilities::availableAudioEffects();
+
+        qDebug() << effectDescriptions.size() << " effect size";
+
+        for(int i = 0; i < effectDescriptions.size(); i++){
+            Phonon::EffectDescription ef = effectDescriptions.at(i);
+            if(QString::compare(ef.name(), "equalizer-10bands") == 0){
+                this->equalizerEffect = new Phonon::Effect(ef);
+                if(path.insertEffect(this->equalizerEffect )){
+                    this->hasEqualizerEffect = true;
+                    this->isEqualizerEnabled = true;
+                    emit equalizerEffectInsertedSignal();
+                    qDebug() << "Effect inserted: " << ef.name();
+                    return true;
+                }else{
+                    qDebug() << "Effect insertion failed: " << ef.name();
+                }
+
+            }
+            qDebug() << ef.name();
+        }
+    }
+    return false;
+}
+
+
+void SymfonieMediaPlayer::removeEqualizerEffect(){
+    if(this->isEqualizerEnabled){
+        this->path.removeEffect(this->equalizerEffect);
+        this->isEqualizerEnabled = false;
+
+        emit equalizerEffectRemovedSignal();
+    }
+}
+
 void SymfonieMediaPlayer::doTimer(int time){
     if(time < 0){
         time = 0;
@@ -118,15 +196,6 @@ Phonon::AudioOutput* SymfonieMediaPlayer::getAudioOutput(){
     return this->audioOutput;
 }
 
-void SymfonieMediaPlayer::init(){
-    //this->setCurrentDirectory(QDir::homePath ());// + "/MyDocs/.sounds";
-    
-    //this->scanDir(QDir::homePath () + "/MyDocs/m", true);
-    // this->scanDir(QDir::homePath () + "/MyDocs/.sounds", true);
-    // qDebug() << "Music location: " << QDesktopServices::storageLocation(QDesktopServices::MusicLocation);
-    //this->setCurrentDirectory(QDesktopServices::storageLocation(QDesktopServices::MusicLocation));
-
-}
 
 void SymfonieMediaPlayer::saveState(){
     int index = this->getCurrentPlaybackIndex();
@@ -141,6 +210,20 @@ void SymfonieMediaPlayer::saveState(){
     SymfonieDb::getInstance()->saveSetting(
             "last_played_index",
             index);
+
+
+    SymfonieDb::getInstance()->saveSetting(
+            "last_played_volume", this->audioOutput->volume());
+
+
+
+    if(this->getCurrentPlaybackIndex() != -1){
+        SymfonieDb::getInstance()->saveSetting("last_played_position", QVariant(this->getMediaObject()->currentTime()));
+    }else{
+        SymfonieDb::getInstance()->saveSetting("last_played_position", QVariant(0));
+    }
+
+    SymfonieDb::getInstance()->saveSetting("is_equalizer_enabled", QVariant(this->isEqualizerEnabled == true ? 1: 0));
 }
 
 
@@ -169,16 +252,18 @@ Phonon::MediaObject *SymfonieMediaPlayer::getMediaObject(){
 }
 
 
+void SymfonieMediaPlayer::setFileFilter(QStringList filterList){
+    this->fileFilterList = filterList;
+}
+
 //remove any entry in the list
 SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlayList){
+
     QDir directory(path);
 
     SymfoniePlayList *playList = new SymfoniePlayList(path);
 
-    QStringList filters;
-    filters << "*.mp3";
-
-    QStringList fileList = directory.entryList(filters);
+    QStringList fileList = directory.entryList(this->fileFilterList);
     QStringList dirList = directory.entryList(
             QStringList(),
             QDir::Dirs|QDir::NoDotAndDotDot|QDir::Drives|QDir::AllDirs
@@ -207,14 +292,18 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlay
 
     }
 
+    if(this->fileFilterList.size() > 0){
 
-    for (int i = 0; i < fileList.size(); i++) {
-        QFileInfo fileInfo(path + "/" +fileList.at(i));
-        QString filePath = fileInfo.canonicalFilePath();
 
-        SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
 
-/*
+        for (int i = 0; i < fileList.size(); i++) {
+            QFileInfo fileInfo(path + "/" +fileList.at(i));
+            QString filePath = fileInfo.canonicalFilePath();
+
+            SymfoniePlayListItemFile *file =  new SymfoniePlayListItemFile(filePath);
+            file->setDisplayName(fileInfo.fileName());
+
+            /*
         SymfonieSong *song = SymfonieSong::findByFilePath(filePath);
         if(song != NULL){
 
@@ -231,7 +320,8 @@ SymfoniePlayList* SymfonieMediaPlayer::scanDir(QString path){//bool isUpdatePlay
         file->setSong(song);
 */
 
-        playList->addFile(file);
+            playList->addFile(file);
+        }
     }
 
     qDebug() << playList->getSize() << "size";
@@ -287,8 +377,29 @@ void SymfonieMediaPlayer::mediaStateChangedSlot(Phonon::State newState, Phonon::
              newState == Phonon::PausedState)
             ){
 
+        if(newState == Phonon::PlayingState){
+           // Timer::singleShot( 10*60*1000, &a, SLOT(quit()) );
+          //  qDebug() << "------------- playing stae triggere";
+
+        }
+
         if(this->seekToBuffer > 0){
+            //grudate volume resuming
+            qreal savedVolume = SymfonieDb::getInstance()->getSetting("last_played_volume", QVariant(0)).toDouble();
+
+            if(savedVolume == 0){
+                savedVolume = .5;
+            }
+
+            this->audioOutput->setVolume(0);
+            qDebug() << "Resume volume to " << savedVolume;
+            this->startGraduateVolumeResuming(savedVolume);
+            //
+
+
             qDebug() <<"state: " << newState << "player seek to " << this->seekToBuffer << " this->player->isSeekable(): " <<  this->player->isSeekable();
+
+            //QTimer::singleShot( 10*60*1000, &this->aboutToFinishSlot(), SLOT(quit()) );
             this->player->seek(this->seekToBuffer);
             this->seekToBuffer = -1;
 
